netapp_ontap.models.subject_alternate_name API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.subject_alternate_name`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SubjectAlternateNameSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SubjectAlternateName object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `dns: List[str] GET POST`

    A list of DNS names for Subject Alternate name extension.

  `email: List[str] GET POST`

    A list of email addresses for Subject Alternate name extension

  `ip: List[str] GET POST`

    A list of IP addresses for Subject Alternate name extension.

  `uri: List[str] GET POST`

    A list of URIs for Subject Alternate name extension.